plut
====

When you're building several web apps simultaneously (increasingly
common in the microservice age) it's annoying to remember which app is
on which port.  plut (port lookup table) does it for you.

To install, run ``pip install plut``. I think there's also a tool
called ``easy_install`` but I don't know how to use that.

Usage
-----

The point of plut is to remember what app is running where. plut does
this by mapping names to ports.  To get the port corresponding to a
name, run: ::

  import plut

  port = plut.port('myservice') # returns an int

plut saves this inside ``~/.plutfile``.  The next time you run
``plut.port``, it'll check if a port already exists and if so, give
you that instead.

You can also do this from the command-line: ::

  plut            # lists all services
  plut rm <name>  # remove a service
  plut <name>     # get the port of a service
